var gulp = require('gulp'),
    jshint = require('gulp-jshint'),
    gutil = require('gulp-util'),
    sass = require('gulp-sass'),
    sourcemaps = require('gulp-sourcemaps'),
    concat = require('gulp-concat'),
    gnf = require('gulp-npm-files');


gulp.task('copyNpmDependenciesOnly', function () {
    gulp.src(gnf(), {base: './'}).pipe(gulp.dest('public/build'));
});

gulp.task('build-css', function () {
    return gulp.src('source/scss/**/*.scss')
        .pipe(sass())
        .pipe(concat('vsbb.styles.css'))
        .pipe(gulp.dest('public/css'));
});

gulp.task('build-css-grid', function () {
    return gulp.src('source/scss/grid.scss')
        .pipe(sass())
        .pipe(concat('vsbb.grid.styles.css'))
        .pipe(gulp.dest('public/css'));
});

gulp.task('build-css-themes', function () {
    return gulp.src('source/scss/themes/**/*.scss')
        .pipe(sass())
        .pipe(concat('vsbb.themes.styles.css'))
        .pipe(gulp.dest('public/css'));
});

/* updated watch task to include sass */

gulp.task('watch', function () {
    gulp.watch('source/javascript/**/*.js', ['build-js','build-js-themes']);
    gulp.watch('source/render/javascript/**/*.js', ['build-render-js']);
    gulp.watch('source/render/scss/**/*.scss', ['build-render-css']);
    gulp.watch('source/scss/**/*.scss', ['build-css','build-css-themes','build-css-grid']);
});

gulp.task('build-js', function () {

    gulp.src('source/javascript/**/*.js')
        .pipe(sourcemaps.init())
        //only uglify if gulp is ran with '--type production'
        .pipe(gutil.env.type === 'production' ? uglify() : gutil.noop())
        .pipe(sourcemaps.write())
        .pipe(concat('vsbb.app.js'))
        .pipe(gulp.dest('public/js'));

});

gulp.task('build-render-js', function () {

    gulp.src('source/render/javascript/**/*.js')
        .pipe(sourcemaps.init())
        //only uglify if gulp is ran with '--type production'
        .pipe(gutil.env.type === 'production' ? uglify() : gutil.noop())
        .pipe(sourcemaps.write())
        .pipe(concat('vsbb.renderApp.js'))
        .pipe(gulp.dest('public/js'));


    gulp.src('source/render/scss/**/*.scss')
        .pipe(sass())
        .pipe(concat('vsbb.renderStyles.css'))
        .pipe(gulp.dest('public/css'));

});

gulp.task('build-render-css', function () {

    gulp.src('source/render/scss/**/*.scss')
        .pipe(sass())
        .pipe(concat('vsbb.renderStyles.css'))
        .pipe(gulp.dest('public/css'));

});

gulp.task('build-js-themes', function () {

    gulp.src('source/javascript/themes/**/*.js')
        .pipe(sourcemaps.init())
        //only uglify if gulp is ran with '--type production'
        .pipe(gutil.env.type === 'production' ? uglify() : gutil.noop())
        .pipe(sourcemaps.write())
        .pipe(concat('vsbb.themes.scripts.js'))
        .pipe(gulp.dest('public/js'));

});

gulp.task('default', function () {
    return gutil.log('Gulp is running!')
});